#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/wdt.h>

#include "usbdrv.h"

#define F_CPU 12000000L 
#include <util/delay.h>

uchar digits[10] = {
  (1<<PORTB0) | (1<<PORTB1) | (1<<PORTB2) | (1<<PORTB4) | (1<<PORTB5) | (1<<PORTB6), // zero
  (1<<PORTB1) | (1<<PORTB5),                                                         // one
  (1<<PORTB0) | (1<<PORTB2) | (1<<PORTB3) | (1<<PORTB5) | (1<<PORTB6),               // two
  (1<<PORTB0) | (1<<PORTB1) | (1<<PORTB3) | (1<<PORTB5) | (1<<PORTB6),               // three
  (1<<PORTB1) | (1<<PORTB3) | (1<<PORTB4) | (1<<PORTB5),                             // four
  (1<<PORTB0) | (1<<PORTB1) | (1<<PORTB3) | (1<<PORTB4) | (1<<PORTB6),               // five
  (1<<PORTB0) | (1<<PORTB1) | (1<<PORTB2) | (1<<PORTB3) | (1<<PORTB4) | (1<<PORTB6), // six
  (1<<PORTB1) | (1<<PORTB5) | (1<<PORTB6),                                           // seven
  (1<<PORTB0) | (1<<PORTB1) | (1<<PORTB2) | (1<<PORTB3) | (1<<PORTB4) | (1<<PORTB5) | (1<<PORTB6), // eight
  (1<<PORTB1) | (1<<PORTB3) | (1<<PORTB4) | (1<<PORTB5) | (1<<PORTB6),               // nine
};

// this gets called when custom control message is received 
USB_PUBLIC uchar usbFunctionSetup(uchar data[8]) { 
  usbRequest_t *rq = (void *)data; // cast data to correct type 
  
  if ((rq->bRequest >= 0) && (rq->bRequest <= 9)) { // custom command is in the bRequest field 
    PORTB = digits[rq->bRequest]; // turn LEDs on 
    return 0; 
  } else
    return 0; 
  
  return 0; // should not get here 
}

int main() { 
  uchar i; 
  
  DDRB = 0x7F; // PB0,1,2,3,4,5,6 as output
  PORTB = 0;
  
  wdt_enable(WDTO_1S); // enable 1s watchdog timer 
  
  usbInit(); 
  
  usbDeviceDisconnect(); // enforce re-enumeration 
  for(i = 0; i<250; i++) { // wait 500 ms 
    wdt_reset(); // keep the watchdog happy 
    _delay_ms(2); 
  } 
  usbDeviceConnect(); 
  
  sei(); // Enable interrupts after re-enumeration 
  
  while(1) { 
    wdt_reset(); // keep the watchdog happy
    usbPoll(); 
  } 
  
  return 0; 
}
